timetokentools.TimeTokenMaker
=============================

.. inheritance-diagram:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker
   :private-bases:

.. autoclass:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker

Special Methods
---------------

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__call__

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker.__str__

   .. note:: Inherited from `__builtin__.object`
